@@ -58,6 +58,7 @@ import com.openexchange.mobile.api.facade.connectors.BaseConnector;
 import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
 import com.openexchange.mobile.api.facade.connectors.responses.ArrayDataResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
+import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.utils.StringUtils;
 
 import org.apache.http.client.methods.HttpUriRequest;
@@ -86,6 +87,16 @@ public class AccountsConnector extends BaseConnector<ArrayDataResponseMto> {
         return accounts;
     }
 
+    public static AccountMto map(Object[][] data, String accountId) {
+        List<AccountMto> accounts = new ArrayList<>(data.length);
+        for (int index = 0; index < data.length; index++) {
+            if (accountId.equals(data[index][0].toString())) {
+                return map(data[index]);
+            }
+        }
+        throw ApiFacadeException.accountNotFound(accountId);
+    }
+
     public static AccountMto map(Object[] data) {
         String id = Integer.toString((Integer) data[0]);
         String accountName = (String) data[2];
