@@ -72,6 +72,7 @@ import com.openexchange.mobile.api.facade.endpoints.requests.PushRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.AuthenticationResponseBody;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.osgi.MultipleAuthenticationServicesHandler;
+import com.openexchange.mobile.api.facade.services.ConfigService;
 import com.openexchange.mobile.api.facade.utils.CookieUtil;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
@@ -94,6 +95,8 @@ public class AuthenticationEndpoint {
 
     private final MultipleAuthenticationServicesHandler authenticationHandler;
 
+    private final ConfigService configService;
+
     @POST
     @Path("/login")
     @Consumes(MediaType.APPLICATION_JSON)
@@ -109,6 +112,8 @@ public class AuthenticationEndpoint {
                 .withUserAgent(userAgent);
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
         SessionData sessionData = authenticationService.authenticate(credentials);
+        sessionData = RequestUtil.enhanceSessionData(request, configuration, userAgent, sessionData);
+        sessionData = configService.addConfiguration(sessionData);
         return buildResponse(sessionData);
     }
 
