@@ -49,11 +49,16 @@
 
 package com.openexchange.mobile.api.facade.services;
 
+import java.util.List;
+
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
+import com.openexchange.mobile.api.facade.connectors.impl.AllCapabilitiesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
+import com.openexchange.mobile.api.facade.connectors.responses.CapabilitiesResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.ConfigResponseMto;
+import com.openexchange.mobile.api.facade.models.Capability;
 import com.openexchange.mobile.api.facade.models.Config;
 
 import lombok.RequiredArgsConstructor;
@@ -65,9 +70,27 @@ public class ConfigService {
 
     public Config getConfig(SessionData sessionData) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
-        ConfigConnector configConnector = connectorFactory.getConfigConnector(sessionData);
-        ConfigResponseMto response = configConnector.execute();
+        Config configuration = retrieveConfiguration(connectorFactory, sessionData);
+        List<Capability> capabilities = retrieveCapabilities(connectorFactory, sessionData);
+        return configuration.withCapabilities(capabilities);
+    }
+
+    public SessionData addConfiguration(SessionData sessionData) {
+        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
+        List<Capability> capabilities = retrieveCapabilities(connectorFactory, sessionData);
+        return sessionData.withCapabilities(capabilities);
+    }
+
+    private Config retrieveConfiguration(ConnectorFactory connectorFactory, SessionData sessionData) {
+        ConfigConnector connector = connectorFactory.getConfigConnector(sessionData);
+        ConfigResponseMto response = connector.execute();
         return ConfigConnector.map(response);
     }
 
+    private List<Capability> retrieveCapabilities(ConnectorFactory connectorFactory, SessionData sessionData) {
+        AllCapabilitiesConnector connector = connectorFactory.getAllCapabilities(sessionData);
+        CapabilitiesResponseMto response = connector.execute();
+        return AllCapabilitiesConnector.map(response);
+    }
+
 }
