@@ -149,10 +149,14 @@ public class RequestUtil {
         String userAgent = getUserAgent(request);
         HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
         checkUserAgent(userAgent, hostConfiguration);
-        return new SessionData(session, cookies)
+        return enhanceSessionData(request, hostConfiguration, userAgent, new SessionData(session, cookies));
+    }
+
+    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String userAgent, SessionData sessionData) {
+        return sessionData
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
                 .withUserAgent(userAgent)
-                .withConfiguration(hostConfiguration);
+                .withConfiguration(configuration);
     }
 
     public String getUserAgent(HttpServletRequest request) {
